@@ -4,8 +4,7 @@ function(x, max.dist=length(x)/3, plotit=TRUE, vario.data=NULL) {
 		call <- match.call()
 		data <- deparse(substitute(x))
 		if (exists("is.R") && is.function(is.R) && is.R()) {	# We are in R
-			require(ts)
-			require(mva)
+			# Now done with Depends: field require(stats)
 			x <- as.ts(x)
 		} else {												# We are in S+
 			x <- as.rts(x)
